========================================================
qiprofile-rest: Quantitative Imaging Profile REST server
========================================================

`qiprofile <http://qiprofile.readthedocs.org/en/latest/>`_ REST API.
See the
`documentation <http://qiprofile-rest.readthedocs.org/en/latest/>`_
for more information.
